@@ -2,15 +2,19 @@
  *                 Mathematical Object Library                 *
  *           Conversion tools Library - Include File           *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.4.4                   *
+ *	             GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006,2007 COLLARD Christophe
- * copyright  2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2007,2008 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class conversion_tools
+/*! \namespace mol
+    \brief Mathematical Object Libraries
+*/
+
+/*! \class mol::conversion_tools
     \brief conversion tools library for basic mathematical objects \n
 
     \htmlonly 
@@ -36,11 +40,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2003, 2004, 2005, 2006, 2007 Christophe COLLARD \n
-	    copyright \htmlonly &#169; \endhtmlonly 2003, 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2003, 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.4.4
-    \date 2003-2007
+    \author copyright \htmlonly &#169; \endhtmlonly 2003, 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2003, 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
+    \date 2003-2008
     \bug none
     \warning none
 */
@@ -82,6 +86,9 @@
 
 using namespace std;
 
+namespace mol
+{
+
 
 //====================
 class conversion_tools
@@ -452,4 +459,7 @@ template <class T> matrix<T> symtensor2matrix (const tensor4<T>& tsr)
 }
 
 
+}
+
+
 #endif
