@@ -2,17 +2,21 @@
  *                 Mathematical Object Library                 *
  * class linear_systems : decl. for Linear Systems Resolution  *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.3.1                   *
+ *                   GNU/linux version 2.0.1                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2008 COLLARD Christophe
  * copyright  2003,2004 CREUSE Emmanuel
  * copyright  2004 DJADEL Karim
- * copyright  2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class linear_systems
+/*! \namespace mol
+    \brief Mathematical Object Libraries
+*/
+
+/*! \class mol::linear_systems
     \brief Library for linear systems resolution
 
     \htmlonly 
@@ -38,13 +42,13 @@
     </FONT>
     \endhtmlonly
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 2003, 2004, 2005, 2006 Christophe COLLARD \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 2003, 2004, 2005, 2006, 2008 Christophe COLLARD \n
              copyright \htmlonly &#169; \endhtmlonly 2003, 2004 Emmanuel CREUSE \n
 	     copyright \htmlonly &#169; \endhtmlonly 2004 Karim DJADEL \n
-	     copyright \htmlonly &#169; \endhtmlonly 2003, 2004, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	     copyright \htmlonly &#169; \endhtmlonly 2003, 2004, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version linux 0.3.1
-    \date 2003-2006
+	     copyright \htmlonly &#169; 2003, 2004, 2005, 2006, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	     copyright \htmlonly &#169; 2003, 2004, 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version linux 2.0.1
+    \date 2003-2008
     \bug none
     \warning none
 */
@@ -77,6 +81,10 @@
 
 // contents :
 
+using namespace std;
+
+namespace mol
+{
 
 
 //==================
@@ -955,5 +963,7 @@ vector<T> BICGSTAB (const matrix_type& matrice, const vector<T>& b, const vector
 }
 
 
+}
+
 
 #endif
