@@ -2,17 +2,21 @@
  *                 Mathematical Object Library                 *
  *	      class matrix:  declarations for matrix	       *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 1.9.34                  *
+ *	             GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  1995,1996,1999,2000,2001,2002,2003,2004,2005,2006,2007 COLLARD Christophe
+ * copyright  1995,1996,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008 COLLARD Christophe
  * copyright  2002,2003,2004 CREUSE Emmanuel
  * copyright  2003,2004 MERCIER Denis
- * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2002,2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class matrix
+/*! \namespace mol
+    \brief Mathematical Object Libraries
+*/
+
+/*! \class mol::matrix
     \brief matrix library \n
 
     \htmlonly 
@@ -38,13 +42,13 @@
     </FONT>
     \endhtmlonly
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Christophe COLLARD \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
              copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004 Emmanuel CREUSE \n
 	     copyright \htmlonly &#169; \endhtmlonly 2003, 2004 Denis MERCIER \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 1.9.34
-    \date 1995-2007
+	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
+    \date 1995-2008
     \bug none
     \warning none
 */
@@ -87,6 +91,9 @@
 
 using namespace std;
 
+namespace mol
+{
+
 
 //=============================
 template <class T> class matrix
@@ -1123,4 +1130,7 @@ template <class Tf> matrix<Tf> merge_columns (const matrix<Tf>& mat1, const matr
 }
 
 
+}
+
+
 #endif
