@@ -2,15 +2,19 @@
  *                   Mathematical Object Library                   *
  *  Class polynom : declaration for polynoms and its derivatives   *
  *                      simula+@metz.ensam.fr                      *
- *	               GNU/linux version 0.2.6                     *
+ *	               GNU/linux version 2.0.0                     *
  *              software under General Public License              *
  *******************************************************************
- * copyright  2002,2003,2004,2005,2006 COLLARD Christophe
- * copyright  2002,2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2002,2003,2004,2005,2006,2008 COLLARD Christophe
+ * copyright  2002,2003,2004,2005,2006,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2002,2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  *******************************************************************/
 
-/*! \class polynom
+/*! \namespace mol
+    \brief Mathematical Object Libraries
+*/
+
+/*! \class mol::polynom
     \brief polynom library \n
 
     \htmlonly 
@@ -36,11 +40,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Christophe COLLARD \n
-	    copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.2.6
-    \date 2002-2006
+    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2008 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
+    \date 2002-2008
     \bug none
     \warning none
 */
@@ -83,6 +87,9 @@
 
 using namespace std;
 
+namespace mol
+{
+
 
 //=================================================
 template <class T> class polynom : public vector<T>
@@ -461,4 +468,7 @@ template <class Tf> polynom<Tf> merge (const polynom<Tf>&, const polynom<Tf>&)
 }
 
 
+}
+
+
 #endif
