@@ -2,19 +2,23 @@
  *                 Mathematical Object Library                 *
  *       class spmatrix : declarations for sparse matrix       *
  *                    simula+@metz.ensam.fr                    *
- *		     GNU/linux version 0.1.6                   *
+ *		     GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright  2004,2005 LAGOUCHE Sophie
  * copyright  2004,2005 CREUSE Emmanuel
  * copyright  2006 FACHE Damien
- * copyright  2006,2007 COLLARD Christophe
- * copyright  2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2006,2007,2008 COLLARD Christophe
+ * copyright  2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
+/*! \namespace mol
+    \brief Mathematical Object Libraries
+*/
+
 /*! 
-  \class spmatrix
+  \class mol::spmatrix
   \brief sparse matrix library
 
   \htmlonly 
@@ -104,11 +108,11 @@
   \authors copyright \htmlonly &#169; \endhtmlonly 2004, 2005 Sophie LAGOUCHE \n
            copyright \htmlonly &#169; \endhtmlonly 2004, 2005 Emmanuel CREUSE \n
            copyright \htmlonly &#169; \endhtmlonly 2006 Damien FACHE \n
-           copyright \htmlonly &#169; \endhtmlonly 2006, 2007 Christophe COLLARD \n
-	   copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	   copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-  \version 0.1.6
-  \date 2004-2007
+           copyright \htmlonly &#169; \endhtmlonly 2006, 2007, 2008 Christophe COLLARD \n
+	   copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	   copyright \htmlonly &#169; 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+  \version 2.0.0
+  \date 2004-2008
   \bug none
   \warning none
 */
@@ -151,6 +155,9 @@
 
 using namespace std;
 
+namespace mol
+{
+
 
 //==================================================
 template <class T> class spmatrix : public matrix<T>
@@ -1677,4 +1684,7 @@ template <class T> void spmatrix<T>::read (const string& filename)
 }
 
 
+}
+
+
 #endif
