@@ -2,16 +2,20 @@
  *                 Mathematical Object Library                 *
  *     class symmatrix:  declarations for symmetric matrix     *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 1.4.8                   *
+ *                   GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2002,2003,2004,2005,2006,2007 COLLARD Christophe
+ * copyright  2002,2003,2004,2005,2006,2007,2008 COLLARD Christophe
  * copyright  2002,2003,2004 CREUSE Emmanuel
- * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2002,2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class symmatrix
+/*! \namespace mol
+    \brief Mathematical Object Libraries
+*/
+
+/*! \class mol::symmatrix
     \brief symmetric matrix library \n
 
     \htmlonly 
@@ -38,12 +42,12 @@
     \endhtmlonly
 
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Christophe COLLARD \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
              copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004 Emmanuel CREUSE \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 1.4.8
-    \date 2002-2007
+	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
+    \date 2002-2008
     \bug none
     \warning none
 */
@@ -82,6 +86,9 @@
 
 using namespace std;
 
+namespace mol
+{
+
 
 //===========================================================
 template <class T> class symmatrix : public virtual matrix<T>
@@ -516,4 +523,7 @@ template <class Tf> symmatrix<Tf> Id2s (int n)
 }
 
 
+}
+
+
 #endif
