@@ -3,15 +3,19 @@
  *                 Mathematical Object Library                 *
  *class symtensor2:declarations for 2nd order symmetric tensors*
  *                    simula+@metz.ensam.fr                    *
- *		     GNU/linux version 0.0.6                   *
+ *		     GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2006,2007 COLLARD Christophe
- * copyright  2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2006,2007,2008 COLLARD Christophe
+ * copyright  2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class symtensor2
+/*! \namespace mol
+    \brief Mathematical Object Libraries
+*/
+
+/*! \class mol::symtensor2
     \brief 2nd order symmetric tensor library \n
 
     \htmlonly 
@@ -39,11 +43,11 @@
 
     Let \f$ E \f$ be a Euclidean space of dimension \f$ n \f$ with basis vectors \f$ \{ e_i \} = (e_1,\ldots,e_n) \f$. A \f$ 2^\text{nd} \f$ order Euclidean tensor \f$ T \f$ is defined as a bilinear application from \f$ E \times E \longrightarrow \Bbb{R} \f$. We use a matrix storage for these tensors. All the basic operations are then already defined, so we just add some specific tensors operators to this class. \n
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2006, 2007 Christophe COLLARD \n
-	    copyright \htmlonly &#169; \endhtmlonly 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.0.6
-    \date 2006-2007
+    \author copyright \htmlonly &#169; \endhtmlonly 2006, 2007, 2008 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
+    \date 2006-2008
     \bug none
     \warning none
 */
@@ -70,6 +74,9 @@
 
 using namespace std;
 
+namespace mol
+{
+
 
 //==========================================================================
 template <class T> class symtensor2 : public symmatrix<T>, public tensor2<T>
@@ -123,4 +130,7 @@ template <class T> symtensor2<T>::symtensor2 (const tensor2<T>& tsr)
 }
 
 
+}
+
+
 #endif
