@@ -2,15 +2,19 @@
  *                 Mathematical Object Library                 *
  *     class tensor2 : declarations for 2nd order tensors      *
  *                    simula+@metz.ensam.fr                    *
- *		     GNU/linux version 0.3.8                   *
+ *		     GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006 COLLARD Christophe
- * copyright  2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2004,2005,2006,2008 COLLARD Christophe
+ * copyright  2004,2005,2006,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class tensor2
+/*! \namespace mol
+    \brief Mathematical Object Libraries
+*/
+
+/*! \class mol::tensor2
     \brief 2nd order tensor library \n
 
     \htmlonly 
@@ -38,11 +42,11 @@
 
     Let \f$ E \f$ be a Euclidean space of dimension \f$ n \f$ with basis vectors \f$ \{ e_i \} = (e_1,\ldots,e_n) \f$. A \f$ 2^\text{nd} \f$ order Euclidean tensor \f$ T \f$ is defined as a bilinear application from \f$ E \times E \longrightarrow \Bbb{R} \f$. We use a matrix storage for these tensors. All the basic operations are then already defined, so we just add some specific tensors operators to this class. \n
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Christophe COLLARD \n
-	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.3.8
-    \date 2004-2006
+    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2008 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2004, 2005, 2006, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2004, 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
+    \date 2004-2008
     \bug none
     \warning none
 */
@@ -65,6 +69,9 @@
 
 using namespace std;
 
+namespace mol
+{
+
 
 //=========================================================
 template <class T> class tensor2 : public virtual matrix<T>
@@ -197,4 +204,7 @@ template <class Tf> tensor2<Tf> dev (tensor2<Tf> tsr)
 }
 
 
+}
+
+
 #endif
