@@ -2,15 +2,19 @@
  *                 Mathematical Object Library                 *
  *      class tensor3 : declarations for 3rd order tensors     *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.5.6                   *
+ *                   GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006,2007 COLLARD Christophe
- * copyright  2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2004,2005,2006,2007,2008 COLLARD Christophe
+ * copyright  2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class tensor3
+/*! \namespace mol
+    \brief Mathematical Object Libraries
+*/
+
+/*! \class mol::tensor3
     \brief 3rd order tensor library \n
 
     \htmlonly 
@@ -36,11 +40,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Christophe COLLARD \n
-	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.5.6
-    \date 2004-2007
+    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
+    \date 2004-2008
     \bug none
     \warning none
 */
@@ -63,6 +67,9 @@
 
 using namespace std;
 
+namespace mol
+{
+
 
 //==============================
 template <class T> class tensor3
@@ -641,4 +648,7 @@ template <class T> tensor3<T>& tensor3<T>::approximation ()
 }
 
 
+}
+
+
 #endif
