@@ -2,17 +2,21 @@
  *                 Mathematical Object Library                 *
  *           class vector : declaration for vectors            *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 1.8.22	               *
+ *	             GNU/linux version 2.0.0	               *
  *            software under General Public License            *
  ***************************************************************
- * copyright  1994,1995,1996,1999,2000,2001,2002,2003,2004,2005,2006,2007 COLLARD Christophe
+ * copyright  1994,1995,1996,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008 COLLARD Christophe
  * copyright  2002,2003,2004 CREUSE Emmanuel
  * copyright  2003,2004 MERCIER Denis
- * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2002,2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class vector
+/*! \namespace mol
+    \brief Mathematical Object Libraries
+*/
+
+/*! \class mol::vector
     \brief vector library \n
 
     \htmlonly 
@@ -41,13 +45,13 @@
     A vector is defined by its size and a pointer on the table of its coordinates. \n
     When the size of a vector is zero there is no table of coordinates attached to the pointer.
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 1994, 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Christophe COLLARD \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 1994, 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
              copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004 Emmanuel CREUSE \n
 	     copyright \htmlonly &#169; \endhtmlonly 2003, 2004 Denis MERCIER \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 1.8.2
-    \date 1994-2007
+	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007,2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
+    \date 1994-2008
     \bug none
     \warning none
 */
@@ -85,7 +89,7 @@
 #endif
 
 #if !defined(__PARAMETERS_H)
-#include "../parameters.h"
+#include "parameters.h"
 #endif
 
 #if !defined(__MATHS_H)
@@ -94,6 +98,9 @@
 
 using namespace std;
 
+namespace mol
+{
+
 
 //=============================
 template <class T> class vector
@@ -150,7 +157,7 @@ template <class T> class vector
     virtual void permute (int,int);     // elements permutation
     template <class Tf> friend void permute (vector<Tf>&, vector<Tf>&);  // vectors permutation
     template <class Tf> friend vector<Tf> abs (const vector<Tf>&);       // give the absolute value of a vector
-    template <class Tf> friend void order (vector<Tf>&);                 // vectors ordering from smallest to biggest
+    template <class Tf> friend vector<int> order (vector<Tf>&);          // vectors ordering from smallest to biggest
     template <class Tf> friend vector<Tf> subvector (const vector<Tf>&, int, int);      // extracts a sub-vector
     template <class Tf> friend vector<Tf> merge (const vector<Tf>&, const vector<Tf>&); // merges 2 vectors
 
@@ -893,13 +900,17 @@ template <class Tf> vector<Tf> abs (const vector<Tf>& v)
 }
 
 
-//--------------------------------------------
-template <class Tf> void order (vector<Tf>& v)
-//--------------------------------------------
+//---------------------------------------------------
+template <class Tf> vector<int> order (vector<Tf>& v)
+//---------------------------------------------------
 {
   // A REVOIR et OPTIMISER
   assert (v.size);
+
   Tf elt;
+  int k;
+  vector<int> positions (v.size, false);
+  for (int i=0; ++i<=v.size; positions[i] = i);
 
   for (int i=1; i<v.size; i++)
     for (int j=i+1; j<=v.size; j++)
@@ -907,7 +918,12 @@ template <class Tf> void order (vector<Tf>& v)
 	{ elt  = v[i];
           v[i] = v[j];
           v[j] = elt;
+	  k = positions[i];
+	  positions[i] = positions[j];
+	  positions[j] = k;
         }
+
+  return positions;
 }
 
 
@@ -942,4 +958,7 @@ template <class Tf> vector<Tf> merge (const vector<Tf>& a, const vector<Tf>& b)
 }
 
 
+}
+
+
 #endif
