@@ -1,10 +1,10 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.2.4                   *
+ *                   GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006,2007, 2008 COLLARD Christophe
- * copyright  2004,2005,2006,2007, 2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2004,2005,2006,2007,2008 COLLARD Christophe
+ * copyright  2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
@@ -51,7 +51,8 @@
 #include "MOL++/maths.h"
 #endif
 
-using namespace std;
+using namespace mol;
+
 
 //==========================
 bool test_maths (int detail)
