@@ -1,13 +1,13 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.1.8                   *
+ *                   GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2004,2005 LAGOUCHE Sophie
  * copyright © 2004,2005 CREUSE Emmanuel
  * copyright © 2006 FACHE Damien
- * copyright © 2006,2007 COLLARD Christophe
- * copyright © 2004,2005,2006,2007 Laboratoire de Physique et Mécanique des Matériaux (LPMM - UMR 7554)
+ * copyright © 2006,2007,2008 COLLARD Christophe
+ * copyright © 2004,2005,2006,2007,2008 Laboratoire de Physique et Mécanique des Matériaux (LPMM - UMR 7554)
  * copyright © 2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
@@ -65,7 +65,7 @@
 #include "tests/affiche.h"
 #endif
 
-using namespace std;
+using namespace mol;
 
 
 //============================
