@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.4.4                   *
+ *                   GNU/linux version 0.4.8                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright  2003,2004,2005,2006 COLLARD Christophe
@@ -100,6 +100,10 @@
 #include "conversion tools-test.h"
 #endif
 
+#if !defined(__ABAQUS_CONVERSION_TOOLS_TEST_H)
+#include "abaqus conversion tools-test.h"
+#endif
+
 #if !defined(__POLYNOMS_TEST_H)
 #include "polynoms-test.h"
 #endif
@@ -179,7 +183,7 @@ main()
 
   cout << endl;
 
-  detail = 1;
+  detail = 0;
   start = clock();
   if (detail)
     //=======================================================================
@@ -263,6 +267,18 @@ main()
 
   cout << endl;
 
+  detail = 0;
+  start = clock();
+  if (detail)
+    //=======================================================================
+    cout<< "------------------abaqus conversion tools------------------- \n";
+    //=======================================================================
+  result *= test_abaqus_conversion_tools(detail);
+  end = clock();
+  cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
+
+  cout << endl;
+
   detail = 0;
   start = clock();
   if (detail)
